==> otp_verification-8.x-1.1.tar.gz: otp_verification/src/MiniorangeOTPVerificationSupport.php <==
<?php

namespace Drupal\otp_verification;

/**
 * @file
 * This class represents support information for customer.
 */
/**
 * @file
 * Contains miniOrange Support class.
 */
class MiniorangeOTPVerificationSupport {
  public $email;
  public $phone;
  public $query;

  public function __construct($email, $phone, $query) {
    $this->email = $email;
    $this->phone = $phone;
    $this->query = $query;

  }

  /**
	 * Send support query.
	 */
	public function sendSupportQuery() {

      $this->query = '[Drupal 8 OTP Verification Module] ' . $this->query;
      $fields = array (
        'company' => $_SERVER['SERVER_NAME'],
        'email' => $this->email,
        'ccEmail' => 'drupalsupport@xecurify.com',
        'phone' => $this->phone,
        'query' => $this->query,
      );
      $field_string = json_encode ($fields);
      $url = MiniorangeOTPVerificationConstants::BASE_URL . '/moas/rest/customer/contact-us';

      $ch = curl_init ( $url );
      curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
      curl_setopt($ch, CURLOPT_ENCODING, "");
      curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
      curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
      curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
      curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
      curl_setopt($ch, CURLOPT_HTTPHEADER, array (
        'Content-Type: application/json',
        'charset: UTF-8',
        'Authorization: Basic'
      ));
      curl_setopt($ch, CURLOPT_POST, TRUE);
      curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
      $content = curl_exec($ch);
	  if (curl_errno($ch)) {
          $error = 'method => sendSupportQuery, file => miniorange_otp_verification_support.php, error =>'.curl_error($ch);
          \Drupal::logger('otp_verification')->error($error);
        return FALSE;
      }
      curl_close ($ch);
      return TRUE;
  }
  public function sendFeatureRequest() {

    $this->query = '[Drupal 8 OTP Verification Module Feature Request] ' . $this->query;
    $fields = array (
      'company' => $_SERVER['SERVER_NAME'],
      'email' => $this->email,
      'ccEmail' => 'drupalsupport@xecurify.com',
      'phone' => $this->phone,
      'query' => $this->query,
    );
    $field_string = json_encode ($fields);
    $url = MiniorangeOTPVerificationConstants::BASE_URL . '/moas/rest/customer/contact-us';

    $ch = curl_init ( $url );
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
    curl_setopt($ch, CURLOPT_ENCODING, "");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array (
      'Content-Type: application/json',
      'charset: UTF-8',
      'Authorization: Basic'
    ));
    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
    $content = curl_exec($ch);
  if (curl_errno($ch)) {
      $error = 'method => sendSupportQuery, file => miniorange_otp_verification_support.php, error =>'.curl_error($ch);
      \Drupal::logger('otp_verification')->error($error);
      return FALSE;
    }
    curl_close ($ch);
    return TRUE;
}
}

==> otp_verification-8.x-1.11.tar.gz: otp_verification/src/MiniorangeOTPVerificationSupport.php <==
<?php

namespace Drupal\otp_verification;

/**
 * @file
 * This class represents support information for customer.
 */

/**
 * @file
 * Contains miniOrange Support class.
 */
class MiniorangeOTPVerificationSupport
{
  public $email;
  public $phone;
  public $query;

  public function __construct($email, $phone, $query)
  {
    $this->email = $email;
    $this->phone = $phone;
    $this->query = $query;
  }

  /**
   * Send support query.
   */
  public function sendSupportQuery()
  {

    $this->query = '[Drupal 8 OTP Verification Module] ' . $this->query;
    $fields = array(
      'company' => $_SERVER['SERVER_NAME'],
      'email' => $this->email,
      'ccEmail' => 'drupalsupport@xecurify.com',
      'phone' => $this->phone,
      'query' => $this->query,
    );
    $field_string = json_encode($fields);
    $url = MiniorangeOTPVerificationConstants::BASE_URL . '/moas/rest/customer/contact-us';

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
    curl_setopt($ch, CURLOPT_ENCODING, "");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
      'Content-Type: application/json',
      'charset: UTF-8',
      'Authorization: Basic'
    ));
    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
    $content = curl_exec($ch);
    if (curl_errno($ch)) {
      $error = 'method => sendSupportQuery, file => miniorange_otp_verification_support.php, error =>' . curl_error($ch);
      \Drupal::logger('otp_verification')->error($error);
      return FALSE;
    }
    curl_close($ch);
    return TRUE;
  }

  public function sendFeatureRequest()
  {

    $this->query = '[Drupal 8 OTP Verification Module Feature Request] ' . $this->query;
    $fields = array(
      'company' => $_SERVER['SERVER_NAME'],
      'email' => $this->email,
      'ccEmail' => 'drupalsupport@xecurify.com',
      'phone' => $this->phone,
      'query' => $this->query,
    );
    $field_string = json_encode($fields);
    $url = MiniorangeOTPVerificationConstants::BASE_URL . '/moas/rest/customer/contact-us';

    $ch = curl_init($url);
    curl_setopt($ch, CURLOPT_FOLLOWLOCATION, TRUE);
    curl_setopt($ch, CURLOPT_ENCODING, "");
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_AUTOREFERER, TRUE);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
    curl_setopt($ch, CURLOPT_MAXREDIRS, 10);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
      'Content-Type: application/json',
      'charset: UTF-8',
      'Authorization: Basic'
    ));
    curl_setopt($ch, CURLOPT_POST, TRUE);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $field_string);
    $content = curl_exec($ch);
    if (curl_errno($ch)) {
      $error = 'method => sendSupportQuery, file => miniorange_otp_verification_support.php, error =>' . curl_error($ch);
      \Drupal::logger('otp_verification')->error($error);
      return FALSE;
    }
    curl_close($ch);
    return TRUE;
  }
}
